<div align="middle">

# pelipy 🐍

![Python](https://img.shields.io/badge/python-%23007ACC.svg?style=for-the-badge&logo=python&logoColor=white)

</div>

## About

Pelipy is an API wrapper for the [Pelican Panel](https://pelican.dev).

just note, this is in the development stages!

## Docs

coming soon 👀

## Installation
```bash
pip install pelipy 
```